===========================
django-import-export-pandas
===========================

django-import-export-pandas is a Django is an addon-application
for django-pandas and django-import-export.

Features:

* support multiple formats (Excel, CSV, JSON, ...
  and everything else that `pandas`_ support)

* GitHub: https://github.com/django-import-export/django-import-export-pandas/
* Free software: BSD license
* PyPI: https://pypi.org/project/django-import-export-pandas/


Requirements
------------

* Python 3.5+
* Django 2.0+

django-import-export requires Python 3.5 and Django 2.0 or newer. See the 1.x
branch for older Python and Django versions where fixes for security issues and
critical errors continue to be released for all officially supported Django
versions.

Contribute
----------

If you'd like to contribute, simply fork `the repository`_, commit your
changes to the **develop** branch (or branch off of it), and send a pull
request.

As most projects, we try to follow PEP8_ as closely as possible. Please bear
in mind that most pull requests will be rejected without proper unit testing.

.. _`PEP8`: https://www.python.org/dev/peps/pep-0008/
.. _`pandas`: https://pandas.pydata.org/
.. _`the repository`: https://github.com/django-import-export/django-import-export-pandas/
